documentationtools.GraphvizNode
===============================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode

.. autoclass:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.canonical_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.edges
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.name
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizNode.GraphvizNode.GraphvizNode.__setstate__
   :noindex:
